/* ************************************************************************** *
 *      Copyright © IPSL/LSCE, XMLIOServer, Avril 2010 - Octobre 2011         *
 * ************************************************************************** */

#include <boost/multi_array.hpp>
#include <boost/shared_ptr.hpp>

#include "xmlioserver.hpp"

#include "attribute_template_impl.hpp"
#include "object_template_impl.hpp"
#include "group_template_impl.hpp"

#include "icutil.hpp"

extern "C"
{
// /////////////////////////////// Définitions ////////////////////////////// //

   // ----------------------- Redéfinition de types ----------------------------

   typedef xmlioserver::tree::CContext * XContextPtr;

   typedef xmlioserver::tree::CGrid      * XGridPtr;
   typedef xmlioserver::tree::CGridGroup * XGridGroupPtr;

   typedef xmlioserver::tree::CFile      * XFilePtr;
   typedef xmlioserver::tree::CFileGroup * XFileGroupPtr;

   typedef xmlioserver::tree::CField      * XFieldPtr;
   typedef xmlioserver::tree::CFieldGroup * XFieldGroupPtr;

   typedef xmlioserver::tree::CDomain      * XDomainPtr;
   typedef xmlioserver::tree::CDomainGroup * XDomainGroupPtr;

   typedef xmlioserver::tree::CAxis      * XAxisPtr;
   typedef xmlioserver::tree::CAxisGroup * XAxisGroupPtr;
   
   // ----------------------- Ajout d'enfant à un parent -----------------------
   
   void xios_xml_tree_add_field(XFieldGroupPtr  parent_, XFieldPtr * child_, const char * child_id, int child_id_size)
   {
      std::string child_id_str; 
      if (!cstr2string(child_id, child_id_size, child_id_str)) return; 
   }
   
   void xios_xml_tree_add_grid(XGridGroupPtr   parent_, XGridPtr * child_, const char * child_id, int child_id_size)
   {
      std::string child_id_str; 
      if (!cstr2string(child_id, child_id_size, child_id_str)) return; 
   }
   
   void xios_xml_tree_add_file(XFileGroupPtr   parent_, XFilePtr * child_, const char * child_id, int child_id_size)
   {
      std::string child_id_str; 
      if (!cstr2string(child_id, child_id_size, child_id_str)) return; 
   }
   
   void xios_xml_tree_add_axis(XAxisGroupPtr   parent_, XAxisPtr * child_, const char * child_id, int child_id_size)
   {
      std::string child_id_str; 
      if (!cstr2string(child_id, child_id_size, child_id_str)) return; 
   }
   
   void xios_xml_tree_add_domain(XDomainGroupPtr parent_, XDomainPtr * child_, const char * child_id, int child_id_size) 
   {
      std::string child_id_str; 
      if (!cstr2string(child_id, child_id_size, child_id_str)) return; 
   }
   
   
   void xios_xml_tree_add_fieldtofile(XFilePtr parent_, XFieldPtr * child_, const char * child_id, int child_id_size)
   {
      std::string child_id_str; 
      if (!cstr2string(child_id, child_id_size, child_id_str)) return; 
   }
   
   void xios_xml_tree_add_fieldgrouptofile(XFilePtr parent_, XFieldGroupPtr * child_, const char * child_id, int child_id_size)
   {
      std::string child_id_str; 
      if (!cstr2string(child_id, child_id_size, child_id_str)) return; 
   }
   
   
   // ----------------------- Affichage de l'arborescence ----------------------
   
   void xios_xml_tree_show   (const char * filename, int filename_size) 
   {
      std::string filename_str; 
      if (!cstr2string(filename, filename_size, filename_str)) return; 
   }
     
   
   // ----------------------- Parsing de document xml --------------------------
   
   void xios_xml_parse_file  (const char * filename  , int filename_size)
   {
      std::string filename_str; 
      if (!cstr2string(filename, filename_size, filename_str)) return; 
   }
   
   void xios_xml_parse_string(const char * xmlcontent, int xmlcontent_size)
   {
      std::string xmlcontent_str; 
      if (!cstr2string(xmlcontent, xmlcontent_size, xmlcontent_str)) return; 
   }
   


} // extern "C"
